# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_notebook_context.ipynb.

# %% auto 0
__all__ = ['get_notebook_data']

# %% ../nbs/01_notebook_context.ipynb 4
from ipykernel.comm import Comm
import asyncio

async def get_notebook_data(timeout=0.1):
    future = asyncio.Future()
    
    def on_msg(msg):
        if not future.done():
            future.set_result(msg['content']['data'])
    
    comm = Comm(target_name='wordslab_notebook_comm', show_warning=False)
    comm.on_msg(on_msg)
    comm.send({'request': 'get_notebook_data'})

    try:
        return await asyncio.wait_for(future, timeout=timeout)
    except asyncio.TimeoutError:
        raise TimeoutError("Failed to receive notebook context from frontend")

# The first call always fails, I didn't find a way around it
try:
    await get_notebook_data()
except:
    ...



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/wordslab-notebooks-lib',
                'doc_host': 'https://wordslab-org.github.io',
                'git_url': 'https://github.com/wordslab-org/wordslab-notebooks-lib',
                'lib_path': 'wordslab_notebooks_lib'},
  'syms': { 'wordslab_notebooks_lib.chat': { 'wordslab_notebooks_lib.chat.NbChat': ('chat.html#nbchat', 'wordslab_notebooks_lib/chat.py'),
                                             'wordslab_notebooks_lib.chat.NbChat.__call__': ( 'chat.html#nbchat.__call__',
                                                                                              'wordslab_notebooks_lib/chat.py'),
                                             'wordslab_notebooks_lib.chat.NbChat.__init__': ( 'chat.html#nbchat.__init__',
                                                                                              'wordslab_notebooks_lib/chat.py')},
            'wordslab_notebooks_lib.context': { 'wordslab_notebooks_lib.context.cell2out': ( 'context.html#cell2out',
                                                                                             'wordslab_notebooks_lib/context.py'),
                                                'wordslab_notebooks_lib.context.cell2xml': ( 'context.html#cell2xml',
                                                                                             'wordslab_notebooks_lib/context.py'),
                                                'wordslab_notebooks_lib.context.get_mime_text': ( 'context.html#get_mime_text',
                                                                                                  'wordslab_notebooks_lib/context.py'),
                                                'wordslab_notebooks_lib.context.get_notebook_context': ( 'context.html#get_notebook_context',
                                                                                                         'wordslab_notebooks_lib/context.py'),
                                                'wordslab_notebooks_lib.context.get_notebook_data': ( 'context.html#get_notebook_data',
                                                                                                      'wordslab_notebooks_lib/context.py'),
                                                'wordslab_notebooks_lib.context.nb2xml': ( 'context.html#nb2xml',
                                                                                           'wordslab_notebooks_lib/context.py')},
            'wordslab_notebooks_lib.core': { 'wordslab_notebooks_lib.core.WordslabNotebooks': ( 'core.html#wordslabnotebooks',
                                                                                                'wordslab_notebooks_lib/core.py'),
                                             'wordslab_notebooks_lib.core.WordslabNotebooks.__init__': ( 'core.html#wordslabnotebooks.__init__',
                                                                                                         'wordslab_notebooks_lib/core.py')},
            'wordslab_notebooks_lib.docs': {},
            'wordslab_notebooks_lib.notebook_context': { 'wordslab_notebooks_lib.notebook_context.get_notebook_data': ( 'notebook_context.html#get_notebook_data',
                                                                                                                        'wordslab_notebooks_lib/notebook_context.py')},
            'wordslab_notebooks_lib.tools': {}}}
